%global __provides_exclude_from	^(%{_libdir}/%{name}/native/.*\\.so|%{_javadir}/%{name}/.*)$

%define buildversion	5550

Name:		jitsi
Version:	2.10.%{buildversion}
Release:	%mkrel 11
Summary:	Open Source Video Calls And Chat
Group:		Networking/Instant messaging
License:	LGPLv2+
URL:		https://jitsi.org/
Source0:	https://download.jitsi.org/jitsi/src/%{name}-src-%{version}.zip
#Source0:	https://download.jitsi.org/jitsi/nightly/src/%%{name}-src-%%{version}.zip
Patch0:		jitsi-2.9-mga-fix_bin_file_path.patch
Patch1:		jitsi-2.9-mga-fix_man_file_package-name.patch
Patch2:		jitsi-2.9-mga-fix_desktop_file_package-name.patch
Patch3:		jitsi-2.10-harfbuzz-header-path.patch
Patch4:		jitsi-2.9-mga-fix_javabin_path.patch

# Upstream
Patch50:	0001-Fix-build-for-as-needed.patch
Patch51:	0001-Silence-warning-about-unused-parameters.patch

# Apply after upstream patches
Patch100:	jitsi-2.9-build-native-modules.patch


BuildRequires:	ant
BuildRequires:	desktop-file-utils
BuildRequires:	git-core
BuildRequires:	gzip
BuildRequires:	java-1.8.0-devel >= 1.8.0

BuildRequires:	x11-proto-devel
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xtst)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(xscrnsaver)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(alsa)

Requires:	java-1.8.0-openjdk


%description
Jitsi is an audio/video Internet phone and instant messenger that
supports some of the most popular instant messaging and telephony protocols
such as SIP, Jabber/XMPP (and hence Facebook and Google Talk), AIM/ICQ,
Yahoo! Messenger, RSS and counting.
Jitsi is completely Open Source / Free Software, and is freely available
under the terms of the GNU Lesser General Public License.


%prep
%setup -q -n %{name}
%autopatch -p1

# precompiled code
find . -name "*.so" -delete

%build
export JAVA_HOME=%{_jvmdir}/java-1.8.0-openjdk
%ant -Dlabel=%{buildversion} rebuild

pushd src/native
for i in clean-native init-native galagonotification globalshortcut-linux hid hwaddressretriever sysactivity; do
  %ant -Dsystem.JAVA_HOME=%{_jvmdir}/java-1.8.0-openjdk $i
done

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_datadir}/applications
mkdir -p %{buildroot}%{_datadir}/pixmaps
mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
mkdir -p %{buildroot}%{_javadir}/%{name}/lib/bundle
mkdir -p %{buildroot}%{_javadir}/%{name}/sc-bundles
mkdir -p %{buildroot}%{_libdir}/%{name}/native

# copy the documentation
cp -pr resources/install/debian/jitsi.1.tmpl %{buildroot}%{_mandir}/man1/%{name}.1
gzip %{buildroot}%{_mandir}/man1/%{name}.1

# copy the launcher script
install -m 755 resources/install/debian/jitsi.sh.tmpl %{buildroot}%{_bindir}/%{name}

# copy the menu icons
cp -pr resources/install/debian/jitsi-32.xpm %{buildroot}%{_datadir}/pixmaps/%{name}-32.xpm
cp -pr resources/install/debian/jitsi-16.xpm %{buildroot}%{_datadir}/pixmaps/%{name}-16.xpm
cp -pr resources/install/debian/jitsi.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

# copy the menu entry
cp -pr resources/install/debian/jitsi.desktop.tmpl %{buildroot}%{_datadir}/applications/%{name}.desktop

desktop-file-install \
	--dir %{buildroot}%{_datadir}/applications \
	--set-icon=%{name} \
	%{buildroot}%{_datadir}/applications/%{name}.desktop

# copy the sc-bundles
cp -pr sc-bundles/*.jar %{buildroot}%{_javadir}/%{name}/sc-bundles/
# remove all slicks
rm -rf %{buildroot}%{_javadir}/%{name}/sc-bundles/*-slick.jar
rm -rf %{buildroot}%{_javadir}/%{name}/sc-bundles/slick*.jar

# copy the os-specific sc-bundles
cp -pr sc-bundles/os-specific/linux/*.jar %{buildroot}%{_javadir}/%{name}/sc-bundles/

# copy the lib jars
cp -pr lib/*.jar %{buildroot}%{_javadir}/%{name}/lib/
cp -pr lib/bundle/* %{buildroot}%{_javadir}/%{name}/lib/bundle/
rm -rf %{buildroot}%{_javadir}/%{name}/lib/bundle/junit.jar

# copy the native libs
%ifarch i386 i586 i686 armv5tl armv7hl
cp -pr lib/native/linux/* %{buildroot}%{_libdir}/%{name}/native/
%else
cp -pr lib/native/linux-64/* %{buildroot}%{_libdir}/%{name}/native/
%endif

# copy the resources
cp -pr resources/install/logging.properties %{buildroot}%{_libdir}/%{name}/
cp -pr lib/felix.client.run.properties %{buildroot}%{_libdir}/%{name}/
cp -pr lib/jitsi-defaults.properties %{buildroot}%{_libdir}/%{name}/
cp -pr resources/install/resources/splash.gif %{buildroot}%{_javadir}/%{name}/

if [ -f lib/jitsi-default-overrides.properties ]
	then
	cp -pr lib/jitsi-default-overrides.properties %{buildroot}%{_libdir}/%{name}/
fi

%files
%doc LICENSE README.md
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_javadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}*
%{_iconsdir}/hicolor/*/*/%{name}.svg
%{_mandir}/man1/%{name}.1*


%changelog
* Wed Mar 30 2022 umeabot <umeabot> 2.10.5550-11.mga9
+ Revision: 1835447
- Mageia 9 Mass Rebuild

* Mon Feb 15 2021 neoclust <neoclust> 2.10.5550-10.mga8
+ Revision: 1675418
- Fix javabin path to allow jitsi to start (mga#27865)

* Thu Sep 03 2020 daviddavid <daviddavid> 2.10.5550-9.mga8
+ Revision: 1621242
- compile with java 8

* Sat Feb 15 2020 umeabot <umeabot> 2.10.5550-8.mga8
+ Revision: 1528457
- Mageia 8 Mass Rebuild

* Tue Aug 20 2019 daviddavid <daviddavid> 2.10.5550-7.mga8
+ Revision: 1430618
- add patch to fix harfbuzz headers path

* Wed Oct 24 2018 daviddavid <daviddavid> 2.10.5550-6.mga7
+ Revision: 1324818
- fix build on armv7hl

* Tue Oct 23 2018 wally <wally> 2.10.5550-5.mga7
+ Revision: 1324696
- remove requires excludes
- enable debug pkgs
- build on all arches again
- add patch to fix native modules build from sources
- add patches from upstream for native module building

* Mon Oct 22 2018 daviddavid <daviddavid> 2.10.5550-4.mga7
+ Revision: 1323685
- build only on ix86 and x86_64

* Sun Sep 23 2018 umeabot <umeabot> 2.10.5550-3.mga7
+ Revision: 1298379
- Mageia 7 Mass Rebuild

* Sat Aug 26 2017 daviddavid <daviddavid> 2.10.5550-2.mga7
+ Revision: 1148189
- disable debug package as debugsourcefiles are empty

* Sat Feb 11 2017 daviddavid <daviddavid> 2.10.5550-1.mga6
+ Revision: 1085760
- new version: 2.10.5550 (stable build)

* Sun Jan 29 2017 daviddavid <daviddavid> 2.9.5545-1.mga6
+ Revision: 1084170
- new version: 2.9.5545 (nightly builds)

* Sun Jan 15 2017 daviddavid <daviddavid> 2.9.5541-1.mga6
+ Revision: 1081764
- new version: 2.9.5541 (nightly builds)

* Sun Oct 30 2016 daviddavid <daviddavid> 2.9.5534-1.mga6
+ Revision: 1064153
- new version: 2.9.5534 (nightly builds)
- rediff patches (P0, P1)
- update description

* Fri May 13 2016 daviddavid <daviddavid> 2.9.5513-1.mga6
+ Revision: 1014522
- new version: 2.9.5513 (nightly builds)

* Mon Apr 25 2016 daviddavid <daviddavid> 2.9.5509-1.mga6
+ Revision: 1006261
- new version: 2.9.5509 (nightly builds)
- rename and rediff all patches
- update description removing unneeded detail of named and versioned package

* Wed Mar 02 2016 umeabot <umeabot> 2.8-4.mga6
+ Revision: 983522
- Rebuild for openssl

* Mon Feb 15 2016 umeabot <umeabot> 2.8-3.mga6
+ Revision: 960724
- Mageia 6 Mass Rebuild

* Mon Jun 22 2015 daviddavid <daviddavid> 2.8-2.mga6
+ Revision: 839117
- add another require excludes

* Sat Jun 20 2015 daviddavid <daviddavid> 2.8-1.mga6
+ Revision: 835881
- new version: 2.8 build 5426 (stable build)
- rename and rediff all patches

* Mon Feb 02 2015 daviddavid <daviddavid> 2.6-1.mga5
+ Revision: 813090
- new version: 2.6 build 5390 (stable build)
- rename and rediff all patches

* Wed Jan 28 2015 daviddavid <daviddavid> 2.5-14.mga5
+ Revision: 812635
- new build version: 5389 (nightly builds)

* Tue Jan 06 2015 daviddavid <daviddavid> 2.5-13.mga5
+ Revision: 808859
- new build version: 5375 (nightly builds)
- exclude all unneeded provides

* Thu Dec 11 2014 daviddavid <daviddavid> 2.5-12.mga5
+ Revision: 802751
- new build version: 5367 (nightly builds)

* Fri Nov 28 2014 daviddavid <daviddavid> 2.5-11.mga5
+ Revision: 799722
- new build version: 5350 (nightly builds)

* Sun Nov 09 2014 daviddavid <daviddavid> 2.5-10.mga5
+ Revision: 796136
- new build version: 5336 (nightly builds)

* Sun Oct 19 2014 daviddavid <daviddavid> 2.5-9.mga5
+ Revision: 791830
- new build version: 5321 (nightly builds)

* Wed Oct 15 2014 umeabot <umeabot> 2.5-8.mga5
+ Revision: 746326
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 wally <wally> 2.5-7.mga5
+ Revision: 730657
- add require excludes

* Sat Sep 27 2014 daviddavid <daviddavid> 2.5-6.mga5
+ Revision: 725987
- new build version: 5306 (nightly builds)

* Tue Sep 16 2014 umeabot <umeabot> 2.5-5.mga5
+ Revision: 680816
- Mageia 5 Mass Rebuild

* Mon Sep 08 2014 daviddavid <daviddavid> 2.5-4.mga5
+ Revision: 673698
- new build version: 5295 (nightly builds)

* Thu Aug 28 2014 daviddavid <daviddavid> 2.5-3.mga5
+ Revision: 669119
- rediff patch 2 (fix_desktop_file_package-name)
- update file list
- new build version: 5290 (nightly builds)

* Sat Aug 16 2014 daviddavid <daviddavid> 2.5-2.mga5
+ Revision: 663984
- new build version: 5277 (nightly builds)

* Thu Aug 07 2014 daviddavid <daviddavid> 2.5-1.mga5
+ Revision: 660799
- rename patches (P0, P1, P2)
- rediff Patch0 to fix new binary file
- improve the description
- add BR on git-core
- add a splash gif file for opening of jitsi
- new version: 2.5 build 5269 (nightly builds)

* Tue Aug 05 2014 luigiwalser <luigiwalser> 2.4-2.mga5
+ Revision: 659861
- switch to java-1.8.0-openjdk

* Sun Mar 16 2014 david-david <david-david> 2.4-1.mga5
+ Revision: 604098
- add patches to remove 'sed' commands (bin, man and desktop files)
- use correct '.jar' files directory
- use correct library files directory
- imported package jitsi

